From b4184548b6a57893bde972d2e5cb517af125c6b4 Mon Sep 17 00:00:00 2001
From: Andrew Yates <ayates@ebi.ac.uk>
Date: Wed, 4 Apr 2012 14:08:50 +0000
Subject: [PATCH] Adding support for other meta keys and aliases

---
 misc-scripts/production_database/sql/tables.sql | 17 ++++++++++-------
 1 file changed, 10 insertions(+), 7 deletions(-)

diff --git a/misc-scripts/production_database/sql/tables.sql b/misc-scripts/production_database/sql/tables.sql
index 1dedad2bd4..f33bddf8df 100644
--- a/misc-scripts/production_database/sql/tables.sql
+++ b/misc-scripts/production_database/sql/tables.sql
@@ -7,13 +7,16 @@
 -- The 'species' table.
 -- Lists the species for which there is a Core database.
 CREATE TABLE species (
-  species_id     INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
-  db_name        VARCHAR(255) NOT NULL, -- Name used in database names.
-  common_name    VARCHAR(255) NOT NULL, -- What we often refer to it as.
-  web_name       VARCHAR(255) NOT NULL, -- Name that the web site is using.
-  taxon          VARCHAR(20),
-  species_prefix VARCHAR(20),
-  is_current     BOOLEAN NOT NULL DEFAULT true,
+  species_id      INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
+  db_name         VARCHAR(255) NOT NULL, -- Name used in database names.
+  common_name     VARCHAR(255) NOT NULL, -- What we often refer to it as.
+  web_name        VARCHAR(255) NOT NULL, -- Name that the web site is using.
+  scientific_name VARCHAR(255) NOT NULL, -- Full name of the species
+  production_name VARCHAR(255) NOT NULL, -- Name that production processes use
+  url_name        VARCHAR(255) NOT NULL, -- Name that is used in URLs
+  taxon           VARCHAR(20),
+  species_prefix  VARCHAR(20),
+  is_current      BOOLEAN NOT NULL DEFAULT true,
 
   -- Columns for the web interface:
   created_by    INTEGER,
-- 
GitLab